==> gradle-src-9.2.1-1-any.pkg.tar.zst: usr/share/java/gradle/src/declarative-dsl-provider/org/gradle/internal/declarativedsl/project/ProjectSchema.kt <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.declarativedsl.project

import org.gradle.internal.declarativedsl.analysis.analyzeEverything
import org.gradle.internal.declarativedsl.common.dependencyCollectors
import org.gradle.internal.declarativedsl.common.gradleDslGeneralSchema
import org.gradle.internal.declarativedsl.evaluationSchema.DefaultInterpretationSequence
import org.gradle.internal.declarativedsl.evaluationSchema.buildEvaluationAndConversionSchema
import org.gradle.internal.declarativedsl.evaluationSchema.ifConversionSupported
import org.gradle.internal.declarativedsl.evaluator.conversion.EvaluationAndConversionSchema
import org.gradle.internal.declarativedsl.software.softwareFeaturesComponent
import org.gradle.plugin.software.internal.SoftwareFeatureRegistry


internal
fun projectInterpretationSequence(
    softwareFeatureRegistry: SoftwareFeatureRegistry
) = DefaultInterpretationSequence(listOf(projectInterpretationSequenceStep(softwareFeatureRegistry)))


fun projectEvaluationSchema(
    softwareFeatureRegistry: SoftwareFeatureRegistry,
): EvaluationAndConversionSchema {
    return buildEvaluationAndConversionSchema(ProjectTopLevelReceiver::class, analyzeEverything) {
        gradleDslGeneralSchema()
        dependencyCollectors()
        ifConversionSupported {
            softwareFeaturesComponent(ProjectTopLevelReceiver::class, softwareFeatureRegistry, withDefaultsApplication = true)
        }
    }
}

==> gradle-src-9.3.1-1-any.pkg.tar.zst: usr/share/java/gradle/src/declarative-dsl-provider/org/gradle/internal/declarativedsl/project/ProjectSchema.kt <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.declarativedsl.project

import org.gradle.internal.declarativedsl.analysis.analyzeEverything
import org.gradle.internal.declarativedsl.common.dependencyCollectors
import org.gradle.internal.declarativedsl.common.gradleDslGeneralSchema
import org.gradle.internal.declarativedsl.evaluationSchema.DefaultInterpretationSequence
import org.gradle.internal.declarativedsl.evaluationSchema.buildEvaluationAndConversionSchema
import org.gradle.internal.declarativedsl.evaluationSchema.ifConversionSupported
import org.gradle.internal.declarativedsl.evaluator.conversion.EvaluationAndConversionSchema
import org.gradle.internal.declarativedsl.software.projectFeaturesComponent
import org.gradle.plugin.software.internal.ProjectFeatureDeclarations


internal
fun projectInterpretationSequence(
    projectFeatureDeclarations: ProjectFeatureDeclarations
) = DefaultInterpretationSequence(listOf(projectInterpretationSequenceStep(projectFeatureDeclarations)))


fun projectEvaluationSchema(
    projectFeatureDeclarations: ProjectFeatureDeclarations,
): EvaluationAndConversionSchema {
    return buildEvaluationAndConversionSchema(ProjectTopLevelReceiver::class, analyzeEverything) {
        gradleDslGeneralSchema()
        dependencyCollectors()
        ifConversionSupported {
            projectFeaturesComponent(ProjectTopLevelReceiver::class, projectFeatureDeclarations, withDefaultsApplication = true)
        }
    }
}
